@@ -8,3 +8,6 @@ globalVariables(c("rainfall", "Y", "ALT.B"))
 globalVariables(c("xend", "yend", "th", "u", "x", "..density..", "r", "ex"))
 
 globalVariables(c("p","qu","chibar","m","absz"))
+
+globalVariables(c("H", "V", "xval", "yval", ".XXidXX.", "xlab", "ylab",
+                  "penalty", "error"))
