@@ -1,12 +1,15 @@
 context("qgev")
 
 test_that("qgev behaves as it should", {
+  skip_on_cran()
+  skip_on_travis()
+
 
     ## get the probabilities that we'll use and sort them
     ## into ascending order for safekeeping
     set.seed(20101111)
     probabilities <- sort(runif(10))
-  
+
     core.sanity.test <- function(xi) {
         base.quantiles <- qgev(probabilities, 0, 1, xi)
         ## check that the values are ascending
@@ -19,7 +22,7 @@ test_that("qgev behaves as it should", {
                      qgev(1 - probabilities, 0, 1, xi, lower.tail=FALSE),
                      label="qgev: lower.tail works correctly")
         ## does log.p work?
-        expect_equal(base.quantiles, 
+        expect_equal(base.quantiles,
                      qgev(log(probabilities), 0, 1, xi, log.p=TRUE),
                      label="qgev: log.p works")
         ## check shift and scale property
@@ -29,9 +32,9 @@ test_that("qgev behaves as it should", {
         expect_equal(shifted, qgev(probabilities, mu, sigma, xi),
                      label="qgev: shift and scale")
     } # Close core.sanity.test
-    
+
     lapply(c(0, seq(-5, 5, length.out=10)), core.sanity.test)
-    
+
     ## known values
     expect_equal(-log(log(2)), qgev(0.5, 0, 1, 0),
                  label="qgev: median match at zero xi")
